@@ -19,8 +19,10 @@ from .colors import green, blue, purple, red, end, bold_green, bold_blue
 
 app = Flask(__name__)
 _started_buttons = {}
-line_sep = "-" * os.get_terminal_size().columns
+# line_sep = "-" * os.get_terminal_size().columns
+line_sep = "-" * 80
 time_header = f"{green}[TIME]{end}"
+logger: logging.Logger = logging.getLogger(__name__)
 # https://realpython.com/python-logging/
 # format edited, datefmt same. Added level
 logging.basicConfig(
@@ -33,10 +35,16 @@ logging.basicConfig(
 @app.route("/<command>/<user>/<choice>/<rand_chars>")
 def _parse_button_commands(command, user, choice, rand_chars):
     global _started_buttons
+    if request.headers["X-Replit-User-Name"] == "":
+        return render_template(
+            "index.html",
+            html='<center><div><script authed="location.reload()" src="https://auth.util.repl.co/script.js"></script></div></center>',
+        )
     if (
         command in _started_buttons
         and user in _started_buttons[command]
         and rand_chars in _started_buttons[command][user]
+        and user == request.headers["X-Replit-User-Name"]
     ):
         _started_buttons[command][user][rand_chars] = choice
         return render_template(
@@ -72,9 +80,13 @@ class Button:
         return f"[{key}]({links.docs}/{parsed})"
 
     def get_choice(self):
-        current = list(_started_buttons[self.command][self.user].values())[0]
+        current = None
         while current is None:
-            current = list(_started_buttons[self.command][self.user].values())[0]
+            _ = list(_started_buttons[self.command][self.user].values())
+            for i in _:
+                if i != None:
+                    current = i
+                    break
         _started_buttons[self.command][self.user] = {}
         return current
 
@@ -109,6 +121,24 @@ class Bot(Client):
             else:
                 ctx.reply(f"description of command: {self.commands[command]['desc']}")
 
+        def __current_default(ctx, *args, **kwargs):
+            __current = "That is not a valid command."
+            __current += (
+                f" You can see the bot docs here {links.docs}"
+                if links.docs is not None
+                else ""
+            )
+            ctx.reply(__current)
+
+        def __not_included_params(ctx, *args, **kwargs):
+            __current = "please include all required params."
+            __current += (
+                f" You can check the bot docs here {links.docs}"
+                if links.docs is not None
+                else ""
+            )
+            ctx.reply(__current)
+
         self.commands = {
             "help": {
                 "call": help_function,
@@ -118,13 +148,15 @@ class Bot(Client):
                 "params": {"command": Param(required=False, default="None")},
             }
         }
+        self._default = __current_default
+        self._not_all_required_params_specified = __not_included_params
         self.token = token
         self.bio = bio
         self.prefix = prefix
         self.alias = {}
         self.listeners = {}
         self.threads_ = []
-        self._call_when_followed = lambda ctx, person_who_followed: logging.info(
+        self._call_when_followed = lambda ctx, person_who_followed: logger.info(
             f"{green}[FILE] BOT.py{end}\n{green}[INFO]{end} @{person_who_followed.username} followed bot"
         )
         self._allow_api = allow_api
@@ -182,7 +214,13 @@ class Bot(Client):
     def follower(self, func):
         self._call_when_followed = func
 
-    def parse_command(self, command: str) -> Dict[str, Any]:
+    def default(self, func):
+        self._default = func
+
+    def fallback_param_not_included_case(self, func):
+        self._not_all_required_params_specified = func
+
+    def parse_command(self, command: str):
         """parses command
 
         `@Example-Bot /say message:hi!`
@@ -204,8 +242,8 @@ class Bot(Client):
 
         output = {
             "options": {},
-            "ping statement": splited[0].strip(),
-            "command": splited[1].lstrip(self.prefix).strip(),
+            "ping statement": splited[0].strip().lower(),
+            "command": splited[1].lstrip(self.prefix).strip().lower(),
         }
         _current_command = None
         current = ""
@@ -213,20 +251,25 @@ class Bot(Client):
             if ":" in i and _current_command is not None:
                 output["options"][_current_command] = current.rstrip()
                 _current_command, current = i.split(":")
+                current += " "
             elif ":" in i and _current_command is None:
                 _current_command, current = i.split(":")
+                current += " "
             else:
                 current += i + " "
         if _current_command is not None:
-            output["options"][_current_command] = current
+            output["options"][_current_command] = current.rstrip()
         return output
 
     def valid_command(self, resp: Dict[str, Any]) -> Tuple[bool, Dict[str, Any]]:
-        """validates command. Returns true if is valid `(True, parsed_json)` or false if not `(False, {'None': None})"""
+        """validates command. Returns true if is valid `(True, parsed_json)` or false if not `(False, {'None': None})`"""
         if resp == {} or resp["comment"] == None:
             return (False, {"None": None})
         parsed = self.parse_command(resp["comment"]["body"])
-        if parsed != {} or parsed["ping statement"] != self.user.username:
+        if (
+            parsed == {}
+            or parsed["ping statement"].strip("@") != self.user.username.lower()
+        ):
             return (False, {"None": None})
         return (True, parsed)
 
@@ -312,7 +355,7 @@ class Bot(Client):
                 i.join()
             sleep(5)
 
-    def run(self, token: str = None) -> None:
+    def run(self, auto_create_docs: bool = True, token: str = None) -> None:
         """mainest runner code"""
         if token is not None and not self.init_:
             super()
@@ -320,19 +363,21 @@ class Bot(Client):
             self.init_ = True
 
         def on_ready(client):
-            logging.info(
+            logger.info(
                 f'{green}[FILE] BOT.py{end}\n{bold_green}[STARTING BOT]{end} Botting "{bold_blue}{client.user.username}{end}"'
             )
 
         self.once("ready", on_ready)
-        self.create_docs()
+        if auto_create_docs:
+            self.create_docs()
 
-        def _run(notif) -> None:
+        def _run(notif_id, notif) -> None:
             """main runner code"""
             # MentionedInPost, MentionedInComment, RepliedToComment, RepliedToPost, AnswerAccepted, MultiplayerJoinedEmail, MultiplayerJoinedLink, MultiplayerInvited, MultiplayerOverlimit, Warning, TeamInvite, TeamOrganizationInvite, Basic, TeamTemplateSubmitted, TeamTemplateReviewedStatus, Annotation, EditRequestCreated, EditRequestAccepted, ReplCommentCreated, ReplCommentReplyCreated, ReplCommentMention, Thread, NewFollower
+            post(self.sid, "markOneAsRead", {"id": notif_id})
             __typename = getattr(notif, "__typename")
             if __typename == "WarningNotification":
-                logging.critical(
+                logger.critical(
                     f"{red}[FILE] BOT.py{end}\n{red}[INFO]{end} bot has been warned"
                 )
             elif __typename == "NewFollowerNotification":
@@ -357,9 +402,9 @@ class Bot(Client):
                         self.commands[c], parsed_json["options"]
                     )
                     if valid:
-                        notif.comment.button = Button(notif.comment.user.username, c)
+                        notif.comment.button = Button(notif.comment.author.username, c)
 
-                        logging.info(
+                        logger.info(
                             f"{green}[FILE] BOT.py{end}\n{green}[INFO] logging command{end}.\n\t{blue}[SUMMARY]{end} {green}command successful{end}\n\t{purple}[EXTRA]{end} Requested command: {parsed_json['command']}"
                         )
                         if self.commands[c]["thread"]:
@@ -373,7 +418,7 @@ class Bot(Client):
                         else:
                             self.commands[c]["call"](notif.comment, **kwargs)
                     else:
-                        logging.info(
+                        logger.info(
                             f"{green}[FILE] BOT.py{end}\n{green}[INFO]{end} logging command\n\t{blue}[SUMMARY]{end} unsucessful: {red}Not all required params specified{end}.\n\t{purple}[EXTRA]{end} Requested command: {parsed_json['command']}"
                         )
                         __current = "please include all required params."
@@ -388,11 +433,11 @@ class Bot(Client):
                 ):
                     c = parsed_json["command"]
                     valid, kwargs = self.get_kwargs(
-                        self.commands[c], parsed_json["options"]
+                        self.listeners[c], parsed_json["options"]
                     )
                     if valid:
                         notif.comment.button = Button(notif.comment.user.username, c)
-                        logging.info(
+                        logger.info(
                             f"{green}[FILE] BOT.py{end}\n{green}[INFO] logging command{end}.\n\t{blue}[SUMMARY]{end} {green}command successful{end}\n\t{purple}[EXTRA]{end} Requested command: {parsed_json['command']}"
                         )
                         for command in self.listeners[c]:
@@ -407,28 +452,20 @@ class Bot(Client):
                             else:
                                 command[c]["call"](notif.comment, **kwargs)
                     else:
-                        logging.info(
+                        logger.info(
                             f"{green}[FILE] BOT.py{end}\n{green}[INFO]{end} logging command\n\t{blue}[SUMMARY]{end} unsucessful: {red}Not all required params specified{end}.\n\t{purple}[EXTRA]{end} Requested command: {parsed_json['command']}"
                         )
-                        __current = "please include all required params."
-                        __current += (
-                            f" You can check the bot docs here {links.docs}"
-                            if links.docs is not None
-                            else ""
-                        )
-                        notif.comment.reply(__current)
+                        self._not_all_required_params_specified(notif.comment)
                 elif "command" in parsed_json:
-                    logging.info(
+                    logger.info(
                         f"{green}[FILE] BOT.py{end}\n{green}[INFO]{end} logging command\n\t{blue}[SUMMARY]{end} unsuccessful: {red}Invalid command{end}.\n\t{purple}[EXTRA]{end} Requested command: {parsed_json['command']}"
                     )
-                    __current = "That is not a valid command."
-                    __current += (
-                        f" You can see the bot docs here {links.docs}"
-                        if links.docs is not None
-                        else ""
-                    )
-                    notif.comment.reply(__current)
+                    self._default(notif.comment)
 
         self.on("notification", _run)
         self.user.notifications.startEvents()
-        serve(app, host="0.0.0.0", port=8080)
+        if auto_create_docs:
+            serve(app, host="0.0.0.0", port=8080)
+        else:
+            while True:
+                pass
