@@ -1,7 +1,7 @@
 """file that handles posting to replit graphql endpoint for queries and mutations"""
 
 import json
-from requests import post as _post, get as _get, delete as _delete
+from requests import Session
 from typing import Dict, Any, List
 from .queries import q
 from .colors import green, end, purple, red, bold_green, bold_blue, blue
@@ -10,6 +10,7 @@ import logging
 import random
 import os
 
+logger: logging.Logger = logging.getLogger(__name__)
 backup: str = "https://graphql-playground.pikachub2005.repl.co/"
 endpoint: str = "https://replit.com/graphql"
 headers: Dict[str, str] = {
@@ -25,6 +26,8 @@ headers: Dict[str, str] = {
 }
 number_convert: List[str] = ["1st", "2nd", "3rd"]
 __reset_status_codes: List[int] = [429, 403, 520, 503, 502, 500]
+s = Session()
+s.headers.update(headers)
 
 
 def post(
@@ -36,8 +39,7 @@ def post(
     __different_endpoint: str = None,
 ):
     """post query with vars to replit graph query language"""
-    _headers = headers
-    _headers["Cookie"] = f"connect.sid={connection}"
+    s.headers.update({"Cookie": f"connect.sid={connection}"})
 
     class InitialRequest:
         def __init__(self):
@@ -53,10 +55,9 @@ def post(
         req.status_code in __reset_status_codes or str(req.status_code).startswith("5")
     ) and number_of_attempts < max_attempts:  # only try 7 times
         current_endpoint = f"{__different_endpoint}?e={int(random.random() * 100)}"
-        req = _post(
+        req = s.post(
             current_endpoint,
             json={"query": (query if raw else q[query]), "variables": vars},
-            headers=_headers,
         )
         if req.status_code in __reset_status_codes or str(req.status_code).startswith(
             "5"
@@ -66,7 +67,7 @@ def post(
                 if number_of_attempts < 3
                 else str(number_of_attempts + 1) + "th"
             )
-            logging.warning(
+            logger.warning(
                 f"{green}[FILE] POST_QL.py{end}\n{red}[WARNING]{end}\n{red}[STATUS CODE] {req.status_code}\n\t{red}[INFO]{end} You have been ratelimited\n\t{bold_blue}[SUMMARY]{end} Retrying query for the {N_TH} time (max retries is 5)"
             )
             number_of_attempts += 1
@@ -91,11 +92,11 @@ def post(
         if len(_text) >= text_max:
             _text = _text[: text_max - 3] + "..."
         if req.status_code == 200:
-            logging.info(
+            logger.info(
                 f"{green}[FILE] POST_QL.py{end}\n{green}[INFO]{end} {bold_green}Successful graphql!{end}\n\t{blue}[SUMMARY]{end} queried replit's graphql with these query and vars.\n\t{purple}[EXTRA]{end}\n\t\t{bold_blue}[QUERY]{end} {query}\n\t\t{bold_blue}[VARS]{end}{_vars}\n\t\t{bold_blue}[RESPONSE]{end} {_text}\n\t\t{bold_blue}[IS RAW QUERY]{end} {raw}\n\t\t{bold_blue}[URL END POINT]{end} {current_endpoint}"
             )
         else:
-            return logging.error(
+            return logger.error(
                 f"{red}[FILE] POST_QL.py{end}\n{red}[STATUS CODE] {req.status_code}\n\t{purple}[EXTRA]{end} {_text}\n\t\t{bold_blue}[QUERY]{end} {query}\n\t\t{bold_blue}[VARS]{end}{_vars}\n\t\t{bold_blue}[IS RAW QUERY]{end} {raw}\n\t\t{bold_blue}[URL END POINT]{end} {current_endpoint}\n\t\t{bold_blue}[RETRY]{end} {retry_for_internal_errors}"
             )
         res = json.loads(req.text)
@@ -111,3 +112,6 @@ def post(
                     return res["data"]
                 else:
                     return res
+
+
+gql = post
