@@ -6,6 +6,8 @@ from typing import Dict, Any, List, Callable as Function
 from threading import Thread
 from ..colors import green, end, red, purple, blue, bold_blue
 
+logger: logging.Logger = logging.getLogger(__name__)
+
 
 class BasicEventEmitter:
     def __init__(self):
@@ -14,7 +16,7 @@ class BasicEventEmitter:
         Thread(target=self._resolve).start()
 
     def on(self, name: str, func: Function[..., Any] = None) -> None:
-        logging.info(
+        logger.info(
             f'{green}[FILE] Utils/EventEmitter.py{end}\n{green}[INFO]{end} tied event "{name}" to function "{func}"\n{purple}[ONCE]{end} {self.__very_secret_var}'
         )
         if name not in self._events:
@@ -46,7 +48,7 @@ class BasicEventEmitter:
         self._events[name]["resolved"] += 1
         self._events[name]["input_args"].append(args)
         self._events[name]["input_kwargs"].append(kwargs)
-        logging.info(
+        logger.info(
             f'{green}[FILE] Utils/EventEmitter.py{end}\n{green}[INFO]{end} Emitted event "{name}"\n\t{blue}[SUMMARY]{end} emitted event "name" with following parameters\n\t{purple}[EXTRA]{end}\n\t\t{bold_blue}[*ARGS]{end} {args}\n\t\t{bold_blue}[**KWARGS]{end} {kwargs}'
         )
 
@@ -64,7 +66,7 @@ class BasicEventEmitter:
                         and len(self._events[i]["input_args"]) > 0
                         and len(self._events[i]["input_kwargs"]) > 0
                     ):
-                        logging.info(
+                        logger.info(
                             f"{green}[FILE] Utils/EventEmitter.py{end}\n{green}[INFO]{end} Resolved Event \"{i}\"\n\t{blue}[SUMMARY]{end} successfully called and executed event \"{i}\" with the following parameters.\n\t{purple}[EXTRA]{end}\n\t\t{bold_blue}[FUNC]{end} {self._events[i]['func']}\n\t\t{bold_blue}[INPUT ARGS]{end} {self._events[i]['input_args'][-1]}\n\t\t{bold_blue}[INPUT KWARGS]{end} {self._events[i]['input_kwargs'][-1]}"
                         )
                         if self._events[i]["once"]:
@@ -87,7 +89,7 @@ class BasicEventEmitter:
             except Exception as e:
                 if type(e) in (RuntimeError, IndexError):
                     continue
-                logging.error(
+                logger.error(
                     f"{green}[FILE] Utils/EventEmitter.py{end}\n{red}[EXCEPTION]{end}",
                     exc_info=True,
                 )
